#!/usr/bin/env/python

""" Work with Pandas Dataframe """

import pandas as pd
from audl.stats.library.data import players
from audl.stats.library.data import players_columns_name
from audl.stats.library.data import player_col_id, player_col_full_name, player_col_first_name, player_col_last_name
from audl.stats.library.data import player_index_id, player_index_full_name, player_index_first_name, player_index_last_name


def _get_players_df():
    return pd.DataFrame(players, columns=players_columns_name)


def _find_value_in_column(substring: str, column_name: str) -> list:
    df = _get_players_df()
    values = []
    for value in list(df[column_name]):
        if substring in value:
            values.append(value)
    return values


def find_players_by_full_name(substring: str) -> list:
    return _find_value_in_column(substring, player_col_full_name)


def _find_row_by_col_args(col_val: str, column_name: str) -> list:
    df = _get_players_df()
    row = df.loc[df[column_name] == col_val]
    return row.values.flatten().tolist()


def find_player_row_by_full_name(full_name: str) -> list:
    return _find_row_by_col_args(full_name, player_col_full_name)


def find_player_row_by_id(player_id: str) -> list:
    return _find_row_by_col_args(player_id, player_col_id)


def _find_rows_with_same_col_value(shared_value: str, column_name: str):
    df = _get_players_df()
    rows = []
    for index, value in enumerate(list(df[column_name])):
        if value == shared_value:
            row = df.iloc[index]
            rows.append(list(row))
    return rows


def find_df_players_who_share_first_name(first_name: str) -> list:
    data = _find_rows_with_same_col_value(first_name, player_col_first_name)
    return pd.DataFrame(data=data, columns=players_columns_name)


def find_df_players_who_share_last_name(last_name: str) -> list:
    data = _find_rows_with_same_col_value(last_name, player_col_last_name)
    return pd.DataFrame(data=data, columns=players_columns_name)


def _find_cell_value_from_col_value(col_value: str, col_name_input: str, col_index_output: int):
    row = _find_row_by_col_args(col_value, col_name_input)
    return row[col_index_output]


def find_player_full_name_from_id(player_id: str) -> str:
    return _find_cell_value_from_col_value(player_id, player_col_id, player_index_full_name)


def find_player_id_from_full_name(full_name: str) -> str:
    return _find_cell_value_from_col_value(full_name, player_col_full_name, player_index_id)


def _get_dataframe_column_as_list(col_name: str):
    return list(_get_players_df()[col_name])


def get_list_players_by_name() -> list:
    return _get_dataframe_column_as_list(player_col_full_name)


def get_list_players_id() -> list:
    return _get_dataframe_column_as_list(player_col_id)



#!/usr/bin/env/python

import json
import pandas as pd
import numpy as np
import requests

from audl.stats.endpoints._base import Endpoint
from audl.stats.static import players
from audl.stats.endpoints.playerprofile import PlayerProfile

from audl.stats.library.game_event import GameEventSimple, GameEventLineup, GameEventReceiver


from audl.stats.library.parameters import quarters_clock_dict
from audl.stats.library.parameters import HerokuPlay
from audl.stats.library.parameters import team_roster_columns_name

#  https://audl-stat-server.herokuapp.com/stats-pages/game/2022-06-11-TOR-MTL


class GameStats(Endpoint):

    def __init__(self, game_id: str):
        super().__init__("https://audl-stat-server.herokuapp.com/stats-pages/game/")
        self.game_id = game_id
        self.json = self._get_json_from_url()
        self.home_team = self._get_home_team_ext_id()
        self.away_team = self._get_away_team_ext_id()

    def _get_home_team_ext_id(self):
        """ 
        Function that return team external id for home team

        Returns
        -------
        ext_team_id: string
            External Team ID (ex: 'royal', 'rush', ...)

        Examples
        --------
        >>> GameStats('2022-06-11-TB-ATL')._get_home_team_ext_id()

        """
        return self.json['game']['team_season_home']['team']['ext_team_id']
        
    def _get_away_team_ext_id(self):
        """ 
        Function that return team external id for away team

        Returns
        -------
        ext_team_id: string
            External Team ID (ex: 'royal', 'rush', ...)

        Examples
        --------
        >>> GameStats('2022-06-11-TB-ATL')._get_away_team_ext_id()

        """
        return self.json['game']['team_season_away']['team']['ext_team_id']

    def _get_url(self):
        """ 
        Function that return complete url

        Returns
        -------
        url: string
            url of the heroku API request
        
        Examples
        --------
        >>> GameStats('2022-06-11-TB-ATL')._get_url()

        """
        return f"{self.base_url}{self.game_id}"
    

    def _get_json_from_url(self):
        """ 
        Function that retrieves requests data as JSON document

        Returns 
        -------
        json_doc: json
            json document from the get requests

        Examples
        --------
        >>> GameStats('2022-06-11-TB-ATL')._get_json_from_url()

        """
        url = self._get_url()
        return requests.get(url).json()

    def get_game_metadata(self):
        """ 
        Function that retrieve game metadata

        Returns
        ------- 
        game_metadata: pandas.Dataframe
            Dataframe with the following columns
                - is_regular_season (bool)
                - home_team, away_team
                - home_score, away_score
                - stadium_name (from location_id)

        Examples
        --------
        >>> GameStats('2022-06-11-TB-ATL').get_game_metadata()

        """
        game = self.json['game']
        df = pd.json_normalize(game)
        return df

    def get_boxscores(self):
        """ 
        Function that return team scores by quarter
        
        Returns
        -------
        df_boxscores: pandas.DataFrame
            Dataframe with team goals by quarter 


        Examples
        --------
        The dataframe should look like this

                    Q1	Q2	Q3	Q4	T
            rush	4	6	4	7	21
            royal	4	7	4	5	20

        >>> GameStats('2022-06-11-TB-ATL').get_boxscores()

        """
        # get scoring times from json 
        scores = self._get_scoring_time()

        # pivot table
        scores = scores.pivot_table(values='scoring_time', 
                index='ext_team_id', columns=['quarter'], aggfunc=np.count_nonzero)

        # add total column
        scores['T'] = scores[list(scores.columns)].sum(axis=1)

        return scores

    def _get_scoring_time(self):
        """ 
        Function that return scoring time for each team

        Returns 
        -------
        scorin_time: pandas.DataFrame   
            Dataframe with the following columns:
                - scoring_time (int): time when point was scored in second
                - ext_team_id (string): team external id ie 'royal'
                - quarter (string): quarter in which point has been scored ie 'Q1'

        Examples
        --------
        The dataframe should look like this

                    scoring_time ext_team_id   quarter
           rush             353         231         Q1
           rush             586         231         Q1
           royal            786         231         Q2

        >>> GameStats('2022-06-11-TB-ATL')._get_scoring_time()

        """
        # get scoring time for both teams
        score_times_home = self.json['game']['score_times_home'][1:]
        score_times_away = self.json['game']['score_times_away'][1:]

        # create dataframes
        home_df = pd.DataFrame(score_times_home, columns=['scoring_time'])
        away_df = pd.DataFrame(score_times_away, columns=['scoring_time'])
        home_df['ext_team_id'] = self._get_home_team_ext_id()
        away_df['ext_team_id'] = self._get_away_team_ext_id()
        scores = pd.concat([home_df, away_df])
        
        # calculate quarter columns
        scores['quarter'] = scores['scoring_time'].apply(
                lambda x: self._get_quarter(x))

        return scores


    @staticmethod
    def _get_quarter(scoring_time):
        """ 
        Function that returns quarter based on scoring time

        Remark: Games are timed with four-quarters of 12 minutes each, 
            including a 15-minute halftime. If the score is tied, a five 
            minutes overtime period is played. If the score remains tied after
            overtime, a second overtime is played in which the first team 
            to score wins.

        Parameters 
        ----------
        scoring_time: int
            time when point was scored in second

        Returns
        -------
        quarter: string 
            ex: 'Q1', 'Q2', 'Q3', 'Q4', 'OT1', 'OT2'
            
        Examples
        --------
        >>> GameStats()._get_quarter(456)

        """
        quarter_end = { 'Q1': 720, 'Q2': 1440, 'Q3': 2160, 'Q4': 2880, 'OT1': 3180 }

        for quarter, end_time in quarter_end.items():
            if scoring_time < end_time:
                return quarter

        return 'OT2'

        
    def get_scores(self):
        """ 
        Function that retrieves scores by times

        Returns
        -------
        scores_df: pandas.DataFrame 
            Dataframe with the following columns:
                - team: "home" or "away"
                - time: time when the team scored
                - goal: who scored the goal
                - assist: who assisted the goal
                - hockey: who made the hockey pass

        Examples
        --------
        >>> GameStats('2022-06-11-TB-ATL').get_scores()

        """
        raise NotImplementedError("This function hasn't been implemented yet!")
        pass

    def get_roster_stats(self):
        """ 
        Function that retrieves stats for all players that played this games
        
        Returns
        -------
        roster_df: pandas.Dataframe
            Dataframe with roster stats

        Examples
        --------
        >>> GameStats('2022-06-11-TB-ATL').get_roster_stats()

        """
        # get external ids for all players that played
        roster_ext_ids = self._get_roster_ext_ids()

        roster_stats = pd.DataFrame()
        for player_id in roster_ext_ids:
            # get all games played in game's season
            player = PlayerProfile(player_id)
            year = self._get_season_from_game_id()
            games = player.get_season_games_stats(year)

            # filter by gameID and add player_id, city_id
            player_stat = games[games['gameID'] == self.game_id]
            player_stat['ext_player_id'] = player_id
            # FIXME: use .iloc instead #  is_home = player_stat.at[0,'isHome']
            is_home = player_stat['isHome'].values[0]
            player_stat['team_abbrev'] = self._get_city_abbrev_from_game_id(is_home)

            roster_stats = pd.concat([roster_stats, player_stat])

        # change columns order
        roster_stats.insert(0, 'ext_player_id', roster_stats.pop('ext_player_id'))
        roster_stats.insert(1, 'team_abbrev', roster_stats.pop('team_abbrev'))

        return roster_stats

    def _get_city_abbrev_from_game_id(self, is_home):
        """ 
        Function that return season from game_id

        Parameters
        ----------
        is_home: bool 
            True if home, False if away


        Returns
        -------
        season : int 
            season year (ex: 2022)


        Examples
        --------
        >>> GameStats('2022-06-11-TB-ATL')._get_city_abbrev_from_game_id(True)
        >>> IND
        >>> GameStats('2022-06-11-TB-ATL')._get_city_abbrev_from_game_id(False)
        >>> ATL

        """
        if is_home:
            return self.game_id.split('-')[4]
        else:
            return self.game_id.split('-')[3]
        


    def _get_season_from_game_id(self):
        """ 
        Function that return season from game_id 

        Returns
        -------
        season : int
            season year 


        Examples
        --------
        >>> GameStats('2022-06-11-TB-ATL')._get_season_from_game_id()
        >>> 2022

        """
        return self.game_id.split('-')[0]


        
    def _get_roster_ext_ids(self):
        """ 
        Function that return all players that played this game (rosterIds)

        Returns
        -------
        roster_ext_ids: list
            List of ext_player_id 

        Examples
        --------
        >>> GameStats('2022-06-11-TB-ATL')._get_roster_ext_ids()
        >>> ['pbisson', 'thodge']

        """
        # get all player_id who have played as list
        rosterHome = self.json['tsgHome']['rosterIds']
        rosterAway= self.json['tsgAway']['rosterIds']
        roster_ids = rosterHome + rosterAway

        # get player_ext_ids
        players = self.get_players_metadata()
        roster_df = players[players['id'].isin(roster_ids)]
        ext_player_ids = roster_df['player.ext_player_id'].tolist()

        return ext_player_ids


    def get_team_stats(self):
        """ 
        Function that retrieves teams stats

        Returns
        -------
        team_stats: pandas.DataFrame
            Dataframe with the following columns:

           'id', 'teamSeasonId', 'gameId', 'source', 'startOnOffense',
           'updateMoment', 'statusId', 'completionsNumer', 'completionsDenom',
           'hucksNumer', 'hucksDenom', 'blocks', 'turnovers', 'oLineScores',
           'oLinePoints', 'oLinePossessions', 'dLineScores', 'dLinePoints',
           'dLinePossessions', 'redZoneScores', 'redZonePossessions', 'road',
           'completionsPerc', 'hucksPerc', 'holdPerc', 'oLineConversionPerc',
           'dLineConversionPerc', 'breakPerc', 'redZoneConversionPerc'

        Examples
        --------
        >>> GameStats('2022-06-11-TB-ATL').get_team_stats()

        """
        tsg_home = self._read_teams_tsg_json(self.json['tsgHome'])
        tsg_home['road'] = 'home'
        tsg_home['team'] = self.home_team
        tsg_away = self._read_teams_tsg_json(self.json['tsgAway'])
        tsg_away['road'] = 'away'
        # concatenate home and away dataframes
        tsg = pd.concat([tsg_home, tsg_away])

        # calculate percentage columns
        tsg['completionsPerc'] = tsg['completionsNumer'] / tsg['completionsDenom'] 
        tsg['hucksPerc'] = tsg['hucksNumer'] / tsg['hucksDenom'] 
        tsg['holdPerc'] = tsg['oLineScores'] / tsg['oLinePoints'] 
        tsg['oLineConversionPerc'] = tsg['oLineScores'] / tsg['oLinePossessions'] 
        tsg['dLineConversionPerc'] = tsg['dLineScores'] / tsg['dLinePossessions'] 
        tsg['breakPerc'] = tsg['dLineScores'] / tsg['dLinePoints'] 
        tsg['redZoneConversionPerc'] = tsg['redZoneScores'] / tsg['redZonePossessions'] 

        return tsg


    def _read_teams_tsg_json(self, team_tsg):
        """ 
        Function that retrieves scoring information in json.tsgHome or json.tsgAway

        Parameters
        ----------
        team_tsg: json 
            json dictionary of tsgHome or tsgAway

        Returns
        -------
        tsg_df: pandas.DataFrame
            dataframe of the tsg
            
        Examples
        --------
        >>> GameStats('2022-06-11-TB-ATL')._read_teams_tsg_json(self.json['tsgHome'])
        >>> GameStats('2022-06-11-TB-ATL')._read_teams_tsg_json(self.json['tsgAway'])

        """
        # read json
        tsg = pd.json_normalize(team_tsg, max_level=1)

        # drop columns
        cols_to_drop = [
                'events', 
                'scoreTimesOur',
                'scoreTimesTheir',
                'rosterIds'
            ]
        tsg = tsg.drop(cols_to_drop, axis=1)

        return tsg


    def get_players_metadata(self):
        """ 
        Function that retrieves all players from both team (even those who 
        are not playing)

        Returns
        -------
        players_metadata: pandas.DataFrame
            Dataframe with all data from json.rostersHome and json.rostersAway
                - player_game_id: id used in events
                - jersey_number
                - player_id
                - first_name:
                - last_name
                - ext_player_id: 'pbisson'
                - ext_team_id: 'royal'
                - city

        Examples
        --------
        >>> GameStats('2022-06-11-TB-ATL').get_players_metadata()

        """
        # get home and away roster
        homeJSON = self.json['rostersHome']
        home_players = pd.json_normalize(homeJSON)
        home_players['road'] = 'home'
        home_players['team'] = self.home_team
        awayJSON = self.json['rostersAway']
        away_players = pd.json_normalize(awayJSON)
        away_players['road'] = 'away'
        away_players['team'] = self.away_team

        # concatenate dataset
        players = pd.concat([home_players, away_players])
        return players 

    def get_teams_metadata(self):
        """ 
        Function that retrieve team and city name for home and away team

        Returns
        -------
        teams_metadata: pandas.DataFrame
            Datafram with all data from games.team_season_home and games.team_season_away
                - team_season_id
                - team_id
                - city: 'Monteal'
                - city_abbrev: 'MTL'
                - name: 'Royal'
                - ext_team_id: 'royal'

        Examples
        --------
        >>> GameStats('2022-06-11-TB-ATL').get_teams_metadata()

        """
        # retrieve df from home and away team
        game = self.json['game']
        home = pd.json_normalize(game['team_season_home'])
        away = pd.json_normalize(game['team_season_away'])
        home['road'] = 'home'
        away['road'] = 'away'

        # concatenate home and away dataframes
        teams = pd.concat([home, away])
        return teams

    def get_lineup_by_points(self):
        """ 
        Function that returns lineup for each point played

        Returns
        -------
        lineup: pandas.DataFrame
            Dataframe with the following columns
            - point (int): ith point played
            - team_on_off (string): team on offense (ext_team_id)
            - team_on_def (string): team on defense (ext_team_id)
            - lineup_def (list): lineup in def (7 players)
            - lineup_off (list): lineup in off (7 players)
            - result (string): ext_team_id of team who won the point
            - scorer (string): ext_player_id of person who scored the point
            - assist (string): ext_player_id of person who assisted
            - hockey (string): ext_player_id of person who made the hockey assist

        Examples
        --------
        >>> GameStats('2022-06-11-TB-ATL').get_lineup_by_points()
        """
        raise NotImplementedError("This function hasn't been implemented yet!")
        pass

    def get_point_results(self, point_events):
        """ 
        Function that returns (events) in a given point for a given team

        Parameters
        ----------
        point_events: json
            json document with all events in a point
            [
                {'t': 20, 'r': 10266, 'x': 3.86, 'y': 66.18},
                {'t': 20, 'r': 10264, 'x': 7.21, 'y': 77.11},
                {'t': 20, 'r': 10255, 'x': -3.07, 'y': 95.77},
            ], 

        See Also
        --------

        Returns
        -------
        points_results: json
            json doc with the following information
            - team_on_off (string): team on offense (ext_team_id)
            - team_on_def (string): team on defense (ext_team_id)
            - lineup_off (list): lineup in off (7 players) (t:1)
            - lineup_def (list): lineup in def (7 players) (t:2)
            - result (string): ext_team_id of team who won the point
            - scorer (string): ext_player_id of person who scored the point (t:22)
            - assist (string): ext_player_id of person who assisted (prev t:20)
            - hockey (string): ext_player_id of person who made the hockey assist 
            - catcher (string): ext_player_id of player who caught the pull
            - center (string): ext_player_id of player who caught the second pass
            - scoring_time (int):
            - timeout_called (bool): True if timeout was called

        """
        raise NotImplementedError("This function hasn't been implemented yet!")
        pass

    def get_events(self):
        """ 
        Function that return the event of each points in sequential order

        Returns
        -------
        events_df: pandas.DataFrame
            Dataframe with the following columns:
                - point (int): ith point played
                - team_on_off (string): team on offense
                - team_on_def (string): team on defense
                - lineup_def (list): lineup in def (7 players)
                - lineup_off (list): lineup in off (7 players)

        
        Examples
        --------
        >>> GameStats('2022-06-11-TB-ATL').get_events()

        """
        raise NotImplementedError("This function hasn't been implemented yet!")
        pass


        
    def print_team_events(self, is_home): 
        """ 
        Function that print events for home and away teams

        Parameters
        ----------
        is_home : bool
            True if we print events of home team, else false

        Examples
        --------
        >>> GameStats('2022-06-11-TB-ATL').print_team_events(True)
        >>> GameStats('2022-06-11-TB-ATL').print_team_events(False)

        """
        events = self.json['tsgHome']['events'] if is_home else self.json['tsgAway']['events']

        # FIXME: convert columns double values to int
        #  cols_to_int = ['t', 'ms', 's', 'c']
        #  for col in cols_to_int:
        #      events[col] = events[col].astype('int', errors='ignore')

        # get players_metadata
        players = self.get_players_metadata()
        players = players[['id', 'player.first_name', 'player.last_name', 
            'player.ext_player_id']]


        # print all events
        for _, row in enumerate(json.loads(events)):
            t = row['t']
            if t in [1,2, 40, 41]:
                # print lineup
                l = row['l']
                lineup = [players[players['id'] == int(player_id)]['player.ext_player_id'].tolist()[0] for player_id in l
]
                print(f"t: {t}; lineup: {lineup}")
            elif t in [3,5,19,20,22]:
                # print receiver
                try:
                    receiver = players[players['id'] == int(row['r'])]['player.ext_player_id'].tolist()[0]
                except: 
                    receiver = 'NaN'
                print(f"t: {t}; r: {receiver}")
            elif t in [14, 15, 42, 43]:
                # print s
                print(f"t: {t}; s: {row['s']}")
            else: 
                print(f"t: {t}")





#!/usr/bin/env/python

import pandas as pd
import requests 
import sys

from datetime import datetime

from audl.stats.endpoints._base import Endpoint
from audl.stats.static import players
from audl.stats.static.miscellaneous import FIRST_SEASON_YEAR

#  https://audl-stat-server.herokuapp.com/web-api/roster-stats-for-player?playerID=cbrock
#  https://audl-stat-server.herokuapp.com/web-api/roster-game-stats-for-player?playerID=cbrock&year=2022


class PlayerProfile(Endpoint):

    def __init__(self, player_id: str):
        super().__init__("https://audl-stat-server.herokuapp.com/web-api/roster-stats-for-player?playerID=")
        self.player_id = player_id


    def _get_url(self):
        """ 
        Function that return complete url

        Returns
        -------
        url: string
            url of the heroku API request
        
        Examples
        --------
        >>> PlayerProfile('cbrock')._get_url()

        """
        return f"{self.base_url}{self.player_id}"

    def get_regular_seasons_career(self):
        """ 
        Function that return a player's regular season stats as dataframe

        Returns
        -------
        regular_season: pandas.DataFrame
            dataframe with player regular season stats
            

        Examples
        --------
        >>> PlayerProfile('cbrock').get_regular_seasons_career()

        """
        try: 
            # create dataframe
            url = self._get_url()
            results = requests.get(url).json()
            df = pd.DataFrame(results['stats'])

            #  sort by regSeason
            regular_season = df[df['regSeason'] == True]

            # drop regSeason column
            #  regular_season = regular_season.drop(columns=['regSeason'], axis=1)

            return regular_season
        except: 
            print(f'An error has occured when fetching regular season dataframe')
            sys.exit(1)


    def get_playoffs_career(self):
        """ 
        Function that returns a player's playoff stats as dataframe

        Returns
        -------
        playoffs: pandas.DataFrame
            dataframe with player playoffs stats
            

        Examples
        --------
        >>> PlayerProfile('cbrock').get_playoffs_career()

        """
        try: 
            # create dataframe
            url = self._get_url()
            results = requests.get(url).json()
            df = pd.DataFrame(results['stats'])

            #  sort by regSeason
            playoffs = df[df['regSeason'] == False]

            # drop regSeason column
            #  playoffs = playoffs.drop(columns=['regSeason'], axis=1)

            return playoffs 
        except: 
            print(f'An error has occured when fetching playoffs dataframe')
            sys.exit(1)

    def get_season_games_stats(self, year):
        """ 
        Function that returns stats per game in a given season

        Parameters
        ----------
        year: int
            season

        Returns
        -------
        season_games: pandas.DataFrame


        Examples
        --------
        >>> PlayerProfile('cbrock').get_season_games_stats(2022)

        """
        try:
            url = f"https://audl-stat-server.herokuapp.com/web-api/roster-game-stats-for-player?playerID={self.player_id}&year={year}"
            results = requests.get(url).json()
            df = pd.DataFrame(results['stats'])
            return df
        except:
            print(f'An error has occured when fetching season stats dataframe')
            sys.exit(1)

    def get_career_games_stats(self):
        """ 
        Function that return dataframe of all games played by a player

        Returns
        -------
        career_games: pandas.DataFrame
            dataframe with all games played

        Examples
        --------
        >>> PlayerProfile('cbrock').get_career_games_stats()

        """
        df = pd.DataFrame()
        current_year = int(datetime.today().strftime('%Y'))
        for year in range(FIRST_SEASON_YEAR, current_year +1):
            df_season = self.get_season_games_stats(year)
            df = df.append(df_season)
        return df

        
        
        




import setuptools
import pathlib

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="audl",
    version="0.0.6",
    license='MIT',
    author="yukikongju",
    author_email="yukikongju@outlook.com",
    description="Unofficial audl api",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/yukikongju/audl",
    install_requires=[
        'pandas',
        'requests',
        'lxml',
        'html5lib',
        'pdoc3'
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    packages=setuptools.find_packages(),
    python_requires=">=3.7",
    keywords=[
        "audl",
        "audl.com",
        "ultimate frisbee",
    ],
)



import pandas as pd
from abc import ABC


class GameEvent(ABC):

    def __init__(self, row, description):
        """ 
        param: 
            - description (string): description of event
            - row (json): json document [t,l,r,x,y,s,c,q]
        """
        self.row = row
        self.description = description

    def print(self):
        pass

    def _read_json_dict(self):
        pass
        

class GameEventSimple(GameEvent):

    """ Game Event with only t """

    def __init__(self, code_type, description, json_dict):
        super().__init__(code_type, json_dict)

    def print(self):
        print(f"t: {self.code_type}")
        

class GameEventLineup(GameEvent):

    """ Game Event with lineup l """

    def __init__(self, code_type, description, json_dict):
        super().__init__(code_type, json_dict)

    def print(self):
        pass
        
        
class GameEventReceiver(GameEvent):

    """ Game Event with receiver r """

    def __init__(self, code_type, description, json_dict):
        super().__init__(code_type, json_dict)

    def print(self):
        pass

        
class GameEventS(GameEvent):

    """ Game Event with s """

    def __init__(self, code_type, description, json_dict):
        super().__init__(code_type, json_dict)

    def print(self):
        pass








#!/usr/bin/env/python

import sys
import pandas as pd
import requests
from audl.stats.endpoints._base import Endpoint


#  https://audl-stat-server.herokuapp.com/web-api/team-stats?limit=50&year=2019&perGame=true&opponent=true

class TeamStats(Endpoint):

    def __init__(self, season, per, team):
        """ 
        Parameters
        ----------
        season: string or int
            choices: ['career', 2022, 2019, ..., 2012]
        per: string
            choices: ['total', 'game']
        team: string
            choices: ['team', 'opponent']


        Examples
        --------
        >>> TeamStats('career', 'total', 'team')
        >>> TeamStats(2022, 'game', 'opponent')

        """

        super().__init__("https://audl-stat-server.herokuapp.com/web-api/team-stats?limit=50")
        self.season = season
        self.per = per
        self.team = team

    def get_table(self):
        """
        Function that return page results table as dataframe

        Returns
        -------
        df: pandas.DataFrame
            dataframe of all team stats


        Raises
        ------



        Examples
        --------
        >>> TeamStats(2019, 'game', 'opponent').get_table()
            
        """
        try:
            url = self._get_url()
            results = requests.get(url).json()
            teams = results['stats']
            df = pd.DataFrame(teams)
        except:
            print(f'An error has occured when fetching the page results as dataframe')
            sys.exit(1)

        return df


    def _get_url(self):
        """ 
        Function that return complete url

        Returns
        -------
        url: string
            url of the heroku API request
        
        Examples
        --------
        >>> TeamStats(2019, 'game', 'opponent')._get_url()
        >>> https://audl-stat-server.herokuapp.com/web-api/team-stats?limit=50&year=2019&perGame=true&opponent=true

        """
        is_per_game = 'true' if self.per == 'game' else 'false' 
        is_opponent = 'true' if self.team == 'opponent' else 'false'
        if self.season == 'career':
            return f"https://audl-stat-server.herokuapp.com/web-api/team-stats?limit=50&perGame={is_per_game}&opponent={is_opponent}"
        else: 
            return f"https://audl-stat-server.herokuapp.com/web-api/team-stats?limit=50&year={self.season}&perGame={is_per_game}&opponent={is_opponent}"

        



